..
    Copyright (C) 2019 Esteban J. Garcia Gabancho.

    Invenio-SAML is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


Configuration
=============

.. automodule:: invenio_saml.config
   :members:
